@@ -10,6 +10,7 @@ try:
 except Exception as e:
     pass
 DB_PD = os.environ["POLICYENGINE_DB_PASSWORD"]
+GITHUB_MICRODATA_TOKEN = os.environ["POLICYENGINE_GITHUB_MICRODATA_AUTH_TOKEN"]
 
 # Export GAE to to .gac.json and DB_PD to .dbpw in the current directory
 
@@ -18,3 +19,6 @@ with open(".gac.json", "w") as f:
 
 with open(".dbpw", "w") as f:
     f.write(DB_PD)
+
+with open(".github_microdata_token", "w") as f:
+    f.write(GITHUB_MICRODATA_TOKEN)
